#
# spec file for package trace-cmd
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


Name:           trace-cmd
Version:        3.3.2
Release:        1.0.2.1.sr20250402
Summary:        Configuration tool for Ftrace
License:        GPL-2.0-only
Group:          Development/Tools/Debuggers
URL:            https://git.kernel.org/pub/scm/utils/trace-cmd/trace-cmd.git
Source0:        trace-cmd-v%{version}.tar.gz
BuildRequires:  asciidoc
BuildRequires:  fdupes
BuildRequires:  libtraceevent-devel
BuildRequires:  libtracefs-devel
BuildRequires:  libzstd-devel
BuildRequires:  meson
BuildRequires:  source-highlight
BuildRequires:  xmlto
BuildRequires:  zlib-devel
Recommends:     libtraceevent1-plugins

%description
trace-cmd is a command-line tool for configuring Ftrace.

%package python3
Summary:        Python plugin support for trace-cmd
Group:          Development/Libraries/Python
Requires:       %{name} = %{version}-%{release}
Requires:       python3
BuildRequires:  python3-devel
BuildRequires:  swig
Provides:       %{name}-python = %{version}

%description  python3
Python plugin support for trace-cmd

%prep
%autosetup -p1 -n trace-cmd-v%{version}

%build
%meson \
    --default-library=shared \
    -Dhtmldir=%{_docdir}/%{name}
%meson_build
%meson_build docs

%install
%meson_install

%fdupes %buildroot/%_prefix

%files
%{_bindir}/trace-cmd
%{_mandir}/man1/trace-cmd*
%{_mandir}/man5/trace-cmd.dat*
%{_docdir}/%{name}/*.html
%{_datadir}/bash-completion/completions/trace-cmd.bash
%license COPYING
%doc README

%files python3
%{python3_sitearch}/%{name}
%{python3_sitearch}/%{name}/*.so
%{python3_sitearch}/%{name}/ctracecmd.py
%doc Documentation/README.PythonPlugin

%changelog
* Tue Apr 29 2025 Petr Pavlu <petr.pavlu@suse.com>
- Update to version 3.3.2:
  * Add trace-cmd show --max_latency
  * Bail out of trace-cmd reset on invalid options
  * Add trace-cmd reset -k option to keep events
  * New bash completions
  * Update help messages of trace-cmd show for --hist and --trigger options
  * Fix some memory errors
  * Fix sqlhist initialization of variables
  * Fix trace-cmd record demonization stdin redirection to /dev/null
* Tue Feb  4 2025 Andrea Manzini <andrea.manzini@suse.com>
- Update to latest upstream version 3.3.1:
  * Disable function trace option func_stack_trace before clearing filter
  * Fix compression algorithm for files greater than 2GB
  * Update printf format to match unsigned parameters.
- Update to version 3.3.0:
  * Now by default, the output shows the latency lines:
  * Add feature to build with meson from using make
  * Add trace-cmd record --daemonize
  * Add trace-cmd show --buffer-subbuf-size option
    This will display the "subbuf-size" of the instance ring buffer.
    (New Linux kernel featuer added in v6.8)
  * Add trace-cmd show --buffer_percent option
    This will display the "buffer_percent" option, added in v5.0.
  * Add trace-cmd show --hist and --trigger options
    Add options to trace-cmd show to display the hist and trigger contents
    of events.
  * Add new command "sqlhist" that makes trace-cmd do the same work as
    the sqlhist code in libtracefs.
  * Show "buffer_subbuf_size" in trace-cmd stat
  * Add trace-cmd record --subbuf-size option
  * Allow trace-cmd report to read multiple files without using the -i
    option. That is, "trace-cmd report trace*.dat" will now work.
  * Have trace-cmd split work with trace.dat files with multiple instances.
  * Allow trace-cmd split to split out instance buffers
  * Allow trace-cmd record to support -m option when recording from an agent.
  * Fix output file names for trace-cmd split
  * Fix the way filters were applied to trace-cmd report with multiple trace.dat
    files.
  * Fix the trace-cmd reset -d option
  * Fix meson build issue
  * Make some man pages clean ups
  * Fix other minor issues.
- dropped patch: libtracecmd-add-explicit-meson-thread-dependency.patch
- dropped patch: tracecmd-add-explicit-meson-thread-dependency.patch
* Fri May 10 2024 Petr Tesařík <ptesarik@suse.com>
- Build with support for zlib and zstd compression.
* Thu Jun 15 2023 Tony Jones <tonyj@suse.com>
- Add explicit thread dependency for older versions of meson (i.e SLE-15-SP5)
  New patch: libtracecmd-add-explicit-meson-thread-dependency.patch
  New patch: tracecmd-add-explicit-meson-thread-dependency.patch
* Thu Jun 15 2023 Tony Jones <tonyj@suse.com>
- Update to version 3.2
  * Add trace-attach.c to meson build
  * Add initial support for meson
  * Quiet valgrind from reporting forked children
  * Close handle after opening
  * Fix memory leaks of followers
  * Add Makefile target for memory test
  * Update the version to the development
  * Add new command "attach"
  * Add tracecmd_get_tsc2nsec() API
  * Unlock records in tracecmd_iterate_events()
  * Add "IP" to -N argument in help message
  * Remove redundant check of instance in allocate_instance()
  * Free buf_from in error path of tracecmd_compress_copy_from()
  * Update v7 trace.dat documentation to clarify the strings section
  * Do not destroy existing instances
  * Do not extract top level unless told to
  * Fix tracecmd_compress_copy_from() write size return
  * Document filter scope
  * Support global filters
  * Ensure filter is applied to single input file
  * Open code execvp routine to avoid multiple execve syscalls
- Drop patches (upstream):
  * 0001-libtracecmd-Add-initial-support-for-meson.patch
  * 0002-trace-cmd-Add-initial-support-for-meson.patch
* Tue Feb  7 2023 Daniel Wagner <daniel.wagner@suse.com>
- Update to latest upstream version (3.1.6)
  * Make sure 32 bit stat works on large files
  * Fix usage of temp file in trace-cmd stream
  * Do not block when stopping trace-cmd stream threads
  * Fix flushing issue with trace-cmd stream
  * Set default sleep of trace-cmd stream to 1/2 second
  * Remove calls to lseek64() and friends in lieu of defining _FILE_OFFSET_BITS=64
- Sync meson build patch with latest upstream version
  * Documentation is build via extra build target
* Tue Dec 27 2022 Daniel Wagner <daniel.wagner@suse.com>
- Update to latest upstream version (3.1.5)
  - Let subcommand "convert" automatically compress if possible
  - Fix calculation of pipe_size (which defaulted to just page size)
- Build project with Meson
  * add 0001-libtracecmd-Add-initial-support-for-meson.patch
  * add 0002-trace-cmd-Add-initial-support-for-meson.patch
  * remove 0001-build-Only-consider-trace-cmd-documentation.patch
  * remove 0002-build-Obey-package-guidelines-for-bash-completions.patch
* Wed Aug 24 2022 Daniel Wagner <daniel.wagner@suse.com>
- Update to latest upstream version (3.1.2)
  Splitted libtracecmd into a seperate project as it has
  a different release cycle and doesn't align with the
  trace-cmd frontend.
  - Drop 0001-libtracecmd-use-major-version-as-SONAME.patch
  - Drop 0002-trace-cmd-Remove-last-elements-of-local-libtracefs-a.patch
  - Add 0001-build-Only-consider-trace-cmd-documentation.patch
  - Rename makefile-bash.patch to 0002-build-Obey-package-guidelines-for-bash-completions.patch
* Tue Feb 22 2022 olaf@aepfle.de
- Force correct pkgconfig_dir location to fix build
- Force python3 during build
* Thu Jan 20 2022 Dario Faggioli <dfaggioli@suse.com>
- New package, with python plugins
  - Add 0002-trace-cmd-Remove-last-elements-of-local-libtracefs-a.patch
* Thu Jan 20 2022 Dario Faggioli <dfaggioli@suse.com>
- Update to latest upstream version (2.9.6)
  - Drop makefile-lib64.patch (not necessary any longer)
- Depend on libtraceevent and libtracefs own package, instead
  of building (a copy of, at least potentially) them ourselves
- Build libtracecmd (and -devel) as separate package
  - Add 0001-libtracecmd-use-major-version-as-SONAME.patch
  - Drop trace-cmd-rpmlintrc (no more lint errors)
- Some spec file cleanup, e.g.:
  - %%setup --> %%autosetup
  - make --> %%make_build
* Thu Sep 24 2020 Dario Faggioli <dfaggioli@suse.com>
- Upgrade to version 2.9.1
  - Drop 0001-trace-cmd-fix-multiple-definition-compiler-errors.patch
  - Patch is upstream, no backport needed any longer
  - Update plugins location (trace-cmd --> traceevent)
  - No need to explicitly remove kernelshark and its docs
  - They're no longer build with trace-cmd
* Mon Jun  8 2020 Mel Gorman <mgorman@suse.de>
- Add 0001-trace-cmd-fix-multiple-definition-compiler-errors.patch
  - Backport fix for a multiple definition error triggered by gcc 10
* Tue Aug 20 2019 Mel Gorman <mgorman@suse.com>
- Clean spec file using spec-cleaner
* Thu Aug  8 2019 Mel Gorman <mgorman@suse.com>
- Add makefile-bash.patch
  - Installs bash completes as per openSUSE packaging guidelines
- Delete revert-trace-cmd-if-event-fork-exists-use-it-instead-of-ptrace.patch
  - Patch merged upstream
- Delete trace-cmd-asciidoc-fix.patch
  - Patch merged upstream
* Wed Aug  7 2019 Mel Gorman <mgorman@suse.com>
- Remove building of kernelshark package
  - Upstream has separate versioning now for trace-cmd and kernelshark
  - Version tags no longer correspond to the same source
- Upgrade to version 2.8.3
  - Install headers dependencies to correct locations
  - SET SONAME on shared libraries
  - Python3 support
- Upgrade to version 2.8.2
  - Fix a potential issue with buffer run due to non-terminating string
    returned by readlink()
- Upgrade to version 2.8.1
  - Split out kernelshark in preparation for major rewrite.
  - Code refactoring related to the kernelshark split
  - Split out event handling into a separate library
  - Fix memory handling errors, NULL handling, use-after-free, leaks
- Upgrade to version 2.7
  - Memory leak fixes
  - Multiple bug fixes on how splice() is handled to avoid data loss
  - Fix various build warnings
  - Documentation updates for missing options, clarifications on usage
  - Update bash competion handlers for sub-commands
- Upgrade to version 2.6.2
  - Fix memory handling errors, NULL handling, use-after-free
  - Fix filter syntax for make_pid_filter
  - Documentation updates
  - Add bash competion handlers for sub-commands
* Wed Feb 28 2018 tiwai@suse.de
- Fix documentation build with asciidoc (bsc#1075764):
  trace-cmd-asciidoc-fix.patch
* Wed Nov  1 2017 mgorman@suse.com
- Add audit-devel as a build dependency to remove a build warning
- Revert event-fork support as children are not properly traced (bsc#1064552)
  Adds revert-trace-cmd-if-event-fork-exists-use-it-instead-of-ptrace.patch
- Bump release number
* Mon Aug 28 2017 mgorman@suse.com
- Upgrade to version 2.6.1
  - Improved robust handling of malloc failures and corrupted input
  - Improved graphing support
  - Fix bug due to double frees
  - Fix output format oddities
  - Add filtering of specific pids
  - Add bash-completion handler
  - New option: --max-graph-depth to limit graph depth
  - New option: -I remove interrupts from trace
  - New option: -S remove softirqs from trace
  - New option: --ts2secs to convert cycles into seconds
  - Updated makefile-lib64.patch to match upstream Makefile changes
* Wed Oct  5 2016 mel.gorman@microfocus.com
- Upgrade to version 2.6
  - New option: -g for trace-cmd profile on custom events
  - New option: -G to make irqs global events in trace-cmd profile
  - New option: -B and -t options to trace-cmd extract to handle instances
  - New option: -a for all instances in trace-cmd extract
  - New option: -a for all instances for trace-cmd stop, reset, and restart
  - New option: --debug to trace-cmd report that shows markup of the trace.dat file.
  - New option: --by-comm to group tasks together by their names in trace-cmd profile.
  - New plugin: Added plugin for tlb_flush event
  - output: Show actual event paths instead of glob when starting
  - output: Simplify status output at end of trace
  - output: Sort events in trace-cmd profile
  - output: Show instance names in trace-cmd stat
  - Plugins are now allowed to have options
  - Have trace-cmd hist work with instances
- Upgrade to version 2.5.2
  - Added support for tracefs filesystem.
  - profile: Show timestamps of max and mins
  - profile: Add -H for user specified event hooking
  - Have -H in record be saved for report --profile to use
* Wed Jan 28 2015 mgorman@suse.com
- Upgrade to version 2.5.1
  - New command stream: stream to console without files
  - New command profile: live statistic gathering
  - New command stat: show what can be enabled
  - New command hist: histogram of recorded events
  - New command mem: filter a trace for kernel slab allocator calls
  - New option: record --profile will enable the same defaults as used
    with trace-cmd profile
  - New option: report --event filter recorded events based on a regex
  - New option: report --profile produces identical output as trace-cmd profile
    except on recorded data instead of live data.
  - Resets all modifications to existing tracing options on completion
  - Trace multiple PIDs (-P x,y,z)
* Tue Mar 12 2013 mgorman@suse.com
- Upgrade to version 2.0.4
  - Have read splice check for EINTR or EAGAIN
  - Do not block during ring buffer extract
  - Do not block on reads when record is finished
  The read splice check is expected to be necessary for trace-cmd to
  work with Linux kernel versions 3.10 and later.
* Thu Dec 20 2012 tonyj@suse.com
- Upgrade to version v2.0.2
  Changelog:
  - Update README for plugins directory
  - trace-cmd: Move trace-cmd python modules to lib/
  - python: Fix further issues of struct record rename
- Fix libraries to install in /usr/lib64 on relevant archs. This adds
  an openSUSE-specific patch called "makefile-lib64.patch" that will
  not be pushed upstream.
* Mon Oct  8 2012 mgorman@suse.com
- Move to upstream stable version v2.0.1. Previously backported patches
  and openSUSE-specific path patches have been merged upstream in this
  version.
- Allow filtering by function names instead of pointers
- Numberous formatting fixes
- Many small stability fixes in the event parser, libtraceevent and trace-cmd.
  Off-by-one errors, potential memory leaks etc.
- Reduced memory and CPU usage. Closes file descriptors that pin kernel memory,
  avoids loading of python if python plugins are not in use.
* Fri Sep 28 2012 mgorman@suse.com
- Backport patches necessary for the "wakeup" plugin to collect
  actual data and report it without segmentation faults.
* Wed Sep 19 2012 mgorman@suse.com
- Depend on libxslt instead of xsltproc on older releases.
* Mon Sep 17 2012 mgorman@suse.com
- Initial package
